# brlcad-2012.py - Script to collate all patch submissions or BRL-CAD from 2012
# Version: Lost count

from html.parser import HTMLParser
import urllib.request
import csv
from sys import argv

class MyHTMLParser(HTMLParser):
    def __init__(self, rowData, strict=True):
        self.rowData = rowData
        self.links = dict()
        self.previousHref = ''
        super(MyHTMLParser, self).__init__(strict)

    def handle_starttag(self, tag, attrs):
        attrs = dict(attrs)
        if tag == 'a' and 'href' in attrs.keys() and ('/gci/work/download/google/gci2012/' in attrs['href'] or 'sourceforge.net/tracker/' in attrs['href']):
            href = attrs['href']
            if not 'sourceforge.net/tracker/' in attrs['href']:
                href = 'http://www.google-melange.com' + attrs['href']
            self.links[href] = ''
            self.previousHref = href

    def handle_data(self, data):
        if self.previousHref and data:
            filename = data.lower().strip() # Assume it is a filename
            if (('.patch' in filename or '.diff' in filename or '.zip' in filename or '.gz' in filename or '.bz2' in filename) and '/gci/work/download/google/gci2012/' in self.previousHref) or 'sourceforge.net/tracker/' in self.previousHref:
                self.links[self.previousHref] = filename
                print('Filename: {}'.format(filename))
                print('Student: {}, Patch Link: {}, Filename: {}'.format(self.rowData['Student'], self.previousHref, filename))
                writer.writerow({'Student':self.rowData['Student'], 'Patch Link':self.previousHref, 'Filename':filename, 'Status':''})
                  
        self.previousHref = ''
                
                

if len(argv) < 3:
    print("Usage: brlcad-2012.py INFILE.csv OUTFILE.csv")
    exit(1)

inputFile = open(argv[1], newline='')
outputFile = open(argv[2], 'w', newline='')
reader = csv.DictReader(inputFile)
writer = csv.DictWriter(outputFile, ['Student', 'Patch Link', 'Filename', 'Status'])
writer.writeheader()

for row in reader:
    types = row['Type'].split(', ')
    if 'Code' in types or 'Quality Assurance' in types:
        html = urllib.request.urlopen('http://www.google-melange.com/gci/task/view/google/gci2012/' + row['Key'])
        print('Accessing {}'.format('http://www.google-melange.com/gci/task/view/google/gci2012/' + row['Key']))
        parser = MyHTMLParser(row)
        parser.feed(str(html.read(), encoding='utf-8'))
        parser.close()
